@@ -56,3 +56,7 @@ class AiAgentComponent(CompanyAssetModel):
     def has_conditional_filters(self) -> bool:
         """Check if the model has assets restrictions"""
         return len(self.filter_criteria) > 0
+
+    def is_always_on(self) -> bool:
+        """Check if the model is always on"""
+        return len(self.filter_criteria) == 0
\ No newline at end of file
