@@ -1,8 +1,10 @@
 from .country import Country
 from .identifier import StrObjectId
-from .typealiases import ChannelId
+from .typealiases import ChannelId, ContactPointId
 from .message_status_types import Status
-from .message_types import MessageType, MessageSubtype
+from .message_types import MessageType, MessageSubtype, MessageDirection
 from .channel_types import Channel
 from .source_types import SourceType
-from .phone_number import PhoneNumber
\ No newline at end of file
+from .phone_number import PhoneNumber
+from .chats_actions import ChatAction
+from .executor_types import ExecutorType
